sqltriples.Types.URIRefExpression

Package sqltriples :: Module Types :: Class URIRefExpression |
[show private | hide private]
[frames | no frames]

## Class URIRefExpression

    AbstractExpression --+
                         |
                Expression --+
                             |
                            URIRefExpression

    An expression acting as a URIRef.

Method Summary
| `__init__(self, expr, values)`
Inherited from Expression
| ``get_expression`(self)`
Inherited from AbstractExpression
| ``__getitem__`(self, i)`
| ``__len__`(self)`

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net